from setuptools import setup

setup(
    author='Triv Collective',
    author_email='maintainer@triv.co',
    description='A syntax for the web and more...',
    install_requires=['triv'],
    long_description='Download package triv instead',
    name='triv-3v',
    platforms=['all'],
    url='https://pypi.org/project/triv/',
    version='0.49.2',
)
